#!/bin/sh
NAME="Download Center"
PKG_PATH=/usr/local/AppCentral/download-center
TR_DAEMON=$PKG_PATH/bin/transmissiond
DLC_DAEMON=$PKG_PATH/bin/dlc-daemon
WATCH_DAEMON=$PKG_PATH/bin/watch_dir
USER=root
STOP_TIMEOUT=10
# This directory stores some runtime information, like torrent files 
# and links to the config file, which itself can be found in 
# /usr/builtin/etc/transmissiond/settings.json
CONFIG_DIR="$PKG_PATH/etc"

# Default options for daemon, see transmission-daemon(1) for more options
OPTIONS="--config-dir $CONFIG_DIR"

export PATH="${PATH:+$PATH:}/sbin"
#export LD_LIBRARY_PATH="$PKG_PATH/lib:$PKG_PATH/lib64"

[ -x $TR_DAEMON ] || exit 0

. /lib/lsb/init-functions

start_daemon () {
    start-stop-daemon --start \
    --chuid $USER \
    --exec $TR_DAEMON -- $OPTIONS
    start-stop-daemon --start \
    --chuid $USER \
    --exec $DLC_DAEMON
}

wait_pid () {
    DAEMON=`basename $1`
    TIME=0
    TIMEOUT=$2

    while [ $TIME -lt $TIMEOUT ]; do
        pidof $DAEMON > /dev/null 2>&1
        STATUS=`echo $?`

        if [ $STATUS -eq 1 ]; then
            return 1
        fi

        TIME=$((TIME+1))
        sleep 1
    done
}

case "$1" in
    start)
        echo "Starting $NAME"
		/usr/local/AppCentral/download-center/bin/transmissiond --config-dir /usr/local/AppCentral/download-center/etc --no-watch-dir
		/usr/local/AppCentral/download-center/bin/dlc-daemon
		/usr/local/AppCentral/download-center/bin/watch_dir &
        ;;
    stop)
        echo "Stopping $NAME"

        start-stop-daemon --stop --quiet \
            --exec $TR_DAEMON --retry $STOP_TIMEOUT \
            --oknodo
        start-stop-daemon --stop --quiet \
            --exec $DLC_DAEMON --retry $STOP_TIMEOUT \
            --oknodo
        start-stop-daemon --stop --quiet \
            --exec $WATCH_DAEMON --retry $STOP_TIMEOUT \
            --oknodo

        wait_pid $TR_DAEMON $STOP_TIMEOUT
        ;;
    reload)
        echo "Reloading $NAME"
        start-stop-daemon --stop --quiet \
            --exec $TR_DAEMON \
            --oknodo --signal 1
        ;;
    restart|force-reload)
        echo "Restarting $NAME"
        start-stop-daemon --stop --quiet \
            --exec $TR_DAEMON --retry $STOP_TIMEOUT \
            --oknodo

        wait_pid $TR_DAEMON $STOP_TIMEOUT

        start_daemon
        ;;
    *)
        echo "Usage: $0 {start|stop|reload|force-reload|restart}"
        exit 2
        ;;
esac

exit 0
